@@ -1,14 +1,13 @@
 import { module, test } from '../qunit';
 import { deprecate } from '../../lib/utils/deprecate';
-import moment from '../../moment';
 
 module('deprecate');
 
 test('deprecate', function (assert) {
     // NOTE: hooks inside deprecate.js and moment are different, so this is can
     // not be test.expectedDeprecations(...)
-    var fn = function () {};
-    var deprecatedFn = deprecate('testing deprecation', fn);
+    var fn = function () {},
+        deprecatedFn = deprecate('testing deprecation', fn);
     deprecatedFn();
 
     assert.expect(0);
